@@ -1,10 +1,10 @@
-# @(#)$Id: Storage.pm 285 2011-07-11 12:40:49Z pjf $
+# @(#)$Id: Storage.pm 321 2011-11-30 00:01:49Z pjf $
 
 package File::MailAlias::Storage;
 
 use strict;
 use namespace::autoclean;
-use version; our $VERSION = qv( sprintf '0.6.%d', q$Rev: 285 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.7.%d', q$Rev: 321 $ =~ /\d+/gmx );
 
 use Date::Format;
 use File::DataClass::Constants;
@@ -104,13 +104,12 @@ sub _write_filter {
 # Private subroutines
 
 sub __original_order {
-   my ($aliases, $lhs, $rhs) = @_;
+   my ($hash, $lhs, $rhs) = @_;
 
    # New elements will be  added at the end
-   return  1 unless (exists $aliases->{ $lhs }->{_order_by});
-   return -1 unless (exists $aliases->{ $rhs }->{_order_by});
-
-   return $aliases->{ $lhs }->{_order_by} <=> $aliases->{ $rhs }->{_order_by};
+   exists $hash->{ $lhs }->{_order_by} or return  1;
+   exists $hash->{ $rhs }->{_order_by} or return -1;
+   return $hash->{ $lhs }->{_order_by} <=> $hash->{ $rhs }->{_order_by};
 }
 
 sub __stamp {
@@ -133,7 +132,7 @@ File::MailAlias::Storage - Storage class file the mail alias file
 
 =head1 Version
 
-0.6.$Revision: 285 $
+0.7.$Revision: 321 $
 
 =head1 Synopsis
 
